This listing is our best-faith, hard-work effort at accurate attribution,
sources, and licenses for everything in Brutal Maze. If you discover an
asset/contribution that is incorrectly attributed or licensed, please contact
us immediately. We are happy to do everything we can to fix or remove the
issue.

## License

Brutal Maze's source code and its icon are released under GNU Affero General
Public License version 3 or later. This means if you run a modified program on
a server and let other users communicate with it there, your server must also
allow them to download the source code corresponding to the modified version
running there.

[![AGPLv3](https://www.gnu.org/graphics/agplv3-155x51.png)](https://www.gnu.org/licenses/agpl.html)

Other creative works retain their original licenses as listed below.

## Tango color palette

Brutal Maze uses [Tango color palette](http://tango.freedesktop.org/Tango_Icon_Theme_Guidelines#Color_Palette)
by the Tango Desktop Project to draw all of its graphics. The palette is
released to the Public Domain.

## Background Music and Sound Effects

Sound Effects Artist - [Tobiasz 'unfa' Karoń](https://freesound.org/people/unfa/)

* License: [CC BY 3.0](https://creativecommons.org/licenses/by/3.0/legalcode)
* brutalmaze/soundfx/heart.ogg ([original](https://freesound.org/s/217456))

Sound Effects Artist - [HappyParakeet](https://freesound.org/people/HappyParakeet/)

* License: [CC0 1.0](https://creativecommons.org/publicdomain/zero/1.0/legalcode)
* brutalmaze/soundfx/lose.ogg ([original](https://freesound.org/s/398068))

Sound Effects Artist - [jameswrowles](https://freesound.org/people/jameswrowles/)

* License: CC0 1.0
* brutalmaze/soundfx/missed.ogg ([original](https://freesound.org/s/380641))

Music Composer - [remaxim](http://opengameart.org/users/remaxim)

* License: [CC-BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/legalcode)
* brutalmaze/soundfx/music.ogg ([original](http://opengameart.org/content/safe-room-theme))

Sound Effects Artist - [MrPork](https://freesound.org/people/MrPork/)

* License: CC0 1.0
* brutalmaze/soundfx/noise.ogg ([original](https://freesound.org/s/257449))

Sound Effects Artist - [suspensiondigital](https://freesound.org/people/suspensiondigital/)

* License: CC0 1.0
* brutalmaze/soundfx/shot-enemy.ogg ([original](https://freesound.org/s/389704))

Sound Effects Artist - [gusgus26](https://freesound.org/people/gusgus26/)

* License: CC0 1.0
* brutalmaze/soundfx/shot-hero.ogg ([original](https://freesound.org/s/121188))

Sound Effects Artist - [braqoon](https://freesound.org/people/braqoon/)

* License: CC0 1.0
* brutalmaze/soundfx/slash-enemy.ogg ([original](https://freesound.org/s/161098))

Sound Effects Artist - [Qat](https://freesound.org/people/Qat/)

* License: CC0 1.0
* brutalmaze/soundfx/slash-hero.ogg ([original](https://freesound.org/s/108333))

Sound Effects Artist - [pepingrillin](https://freesound.org/people/pepingrillin/)

* License: CC0 1.0
* brutalmaze/soundfx/spawn.ogg ([original](https://freesound.org/s/252083))
